#pragma rtGlobals=1		// Use modern global access method.
///////////////////////////////////////////////////////////////////////////////////////
// hi_ExecFunc(func,prefix,suffix,from,to)  
// Execute function whose name is "func" (func is String).
// Input parameter of "func" will be    "%s%03d",prefix,i    where i is an index.
// i varies from "from" to "to", so that the execution of "func" will be repeated
// for ("from" - "to") times.
//
// Example: If function "justprint(str)" is defined as follows....
// 
// Function justprint(str)
//    string str
//    printf "%s\r",str
// End
//
// then the execution of
//
// hiz_ExecFunc("justprint","foo",8,11)
//
// will be resulted as ...
//
// foo008
// foo009
// foo010
// foo011
//
// Hirotake Itoh, Mar 2003
Function hi_ExecFunc(func,prefix,suffix,from,to)
	String func,prefix,suffix
	Variable from,to

	FUNCREF hi_ExecFunc_ProtoFunc f = $func
	String input_str
	Variable i

	for(i=from; i<=to; i+=1)
		sprintf input_str,"%s%03d%s",prefix, i, suffix
		if( f(input_str) == -1 )	// if unknown functionname is passed,
			return -1				// execution is aborted.
		endif
	endfor
end

// hi_ExecFunc_ProtoFunc(input_str)
// This is just a prototype (with a String input).
// prints error message and returns -1.
Function hi_ExecFunc_ProtoFunc(input_str)
	String input_str
	printf "Error in Function Reference\r"
	return -1
End
/// end of hi_ExecFunc and hi_ExecFunc_ProtoFunc /////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////////////////////////
// hi_ExecFunc_panel
// creates a nice panel for hi_ExecFunc
function hi_ExecFunc_panel()
	NewDataFolder/o root:hi_ExecFunc

	String/g root:hi_ExecFunc:func	// contains selected functionname
	String/g root:hi_ExecFunc:Prefix = "twire"
	String/g root:hi_ExecFunc:Suffix = ".txt"
	Variable/g root:hi_ExecFunc:from = 1
	Variable/g root:hi_ExecFunc:to = 99

	NewPanel /W=(646,83,1080,351)	

	DoWindow/C/T/r hi_panel,"Execute function ..."	// name, title
	setdrawenv fname="Arial",fillpat=0,save			// default setting

	// SetVariable
	SetVariable Prefix_panel,pos={12,33},size={399,18},title="Prefix:"
	SetVariable Prefix_panel,font="Courier New",value= root:hi_ExecFunc:Prefix
	SetVariable Suffix_panel,pos={12,57},size={140,18},title="Suffix:"
	SetVariable Suffix_panel,font="Courier New",value= root:hi_ExecFunc:Suffix
	SetVariable from_panel,pos={26,85},size={100,18},title="from:"
	SetVariable from_panel,font="Courier New",value= root:hi_ExecFunc:from
	SetVariable to_panel,pos={25,109},size={100,18},title="  to:",font="Courier New"
	SetVariable to_panel,value= root:hi_ExecFunc:to
	
	// Button
	Button hi_exec,pos={274,86},size={62,35},proc=hi_ExecFunc_exec,title="Execute"
	Button hi_quit,pos={341,86},size={45,35},proc=hi_ExecFunc_quit,title="Quit"

	// Popup
	PopupMenu hi_popup pos={10,7},proc=hi_ExecFunc_popup,font="Courier New",title="function:"
	PopupMenu hi_popup value= hi_ExecFunc_MakePopupItems()
	
	// Text
	SetDrawEnv fname="Courier New", save
	SetDrawEnv fsize= 14,fstyle= 1
	DrawText 9,157,"Example"
	DrawText 29,198,"Prefix:"
	DrawText 29,214,"Suffix:"
	DrawText 29,230,"  from:"
	DrawText 29,246,"    to:"
	DrawText 14,182,"function:"
	DrawText 86,182,"hoge"
	DrawText 85,198,"pre"
	DrawText 85,214,"suf"
	DrawText 85,230,"1"
	DrawText 85,246,"5"
	SetDrawEnv fname="Arial"
	DrawText 130,192,"is equivalent to"
	SetDrawEnv linethick= 5,arrow= 1,arrowfat= 2
	DrawLine 132,203,212,203
	DrawText 239,179,"hoge(\"pre001suf\") [enter]"
	DrawText 239,195,"hoge(\"pre002suf\") [enter]"
	DrawText 239,211,"hoge(\"pre003suf\") [enter]"
	DrawText 239,227,"hoge(\"pre004suf\") [enter]"
	DrawText 239,243,"hoge(\"pre005suf\") [enter]"
	DrawText 313,263,"(3-length number)"

	DrawLine 11,135,410,135
	
end
// end of hi_ExecFunc_panel ////////////////////////////////////////////////////////////////

Function/s hi_ExecFunc_MakePopupItems()

	Variable i
	
	// I need only functions which have one parameter
	String desiredFuncList = FunctionList("hi_*",";","NPARAMS:1")

	// however, I don't need buttoncontrol procedure 	
	String btnFuncList = FunctionList("hi_*",";","SUBTYPE:ButtonControl")
	for(i=0; i<=ItemsInList(btnFuncList, ";")-1; i+=1)
		desiredFuncList = RemoveFromList( StringFromList(i, btnFuncList), desiredFuncList, ";")
	endfor

	// besides, I also don't need hi_ExecFunc family
	String EFuncList = FunctionList("hi_ExecFunc*",";","")
	for(i=0; i<=ItemsInList(EFuncList, ";")-1; i+=1)
		desiredFuncList = RemoveFromList( StringFromList(i, EFuncList), desiredFuncList, ";")
	endfor
	
	return desiredFuncList
end

// controls for hi_ExecFunc_panel //////////////////////////////////////////////////////////
function hi_ExecFunc_popup(ctrlname,popnum,popstr) : PopupmenuControl
	String ctrlname,popstr
	Variable popnum
	Svar func = root:hi_ExecFunc:func
	func = popstr
end

Function hi_ExecFunc_quit(ctrlname) : ButtonControl
	String ctrlname
	DoWindow/k hi_panel
	KillDataFolder root:hi_ExecFunc
End

Function hi_ExecFunc_exec(ctrlname) : ButtonControl
	String ctrlname
	Svar func = root:hi_ExecFunc:func
	Svar prefix = root:hi_ExecFunc:Prefix
	Svar suffix = root:hi_ExecFunc:suffix
	Nvar from = root:hi_ExecFunc:from
	Nvar to = root:hi_ExecFunc:to
	
	hi_ExecFunc(func,prefix,suffix,from,to)
End
// end of controls for hi_ExecFunc_panel ///////////////////////////////////////////////////
