#pragma rtGlobals=1		// Use modern global access method.

// hi_LP
//
// Do almost same as 'Image Line Profile' in Image Processing procedure, 
// but the treatment of units is bit enhanced
//
// It seems there are too much global variables.....
Function hi_LP_main()

	NewDataFolder/O :hi_LP_temp	
	Variable/G :hi_LP_temp:TargetPos = 1
	Variable/G :hi_LP_temp:ValFrom
	Variable/G :hi_LP_temp:ValUpto
	Variable/G :hi_LP_temp:Delta = 1
	String/G :hi_LP_temp:VorH = "V"
	
	String/G :hi_LP_temp:GraphName = WinName(0,1)	// top graph
	SVAR GraphName = :hi_LP_temp:GraphName
	String/G :hi_LP_temp:ImageWave = ImageNameList(GraphName, ";")
	SVAR ImageWave = :hi_LP_temp:ImageWave

	// error handling
	if(stringmatch(ImageWave, ""))
		print "There are no images"
		return -1
	endif
	if(stringmatch(ImageWave, "*;*;"))
		print "Too many images"
		return -1
	endif
	
	ImageWave = ImageWave[0, strlen(ImageWave)-2]	// remove the last note ";"

	Variable colnum = DimSize($ImageWave, 1)
	Variable rownum = DimSize($ImageWave, 0)
	Make/O/D/N=(colnum) Vwv
	Make/O/D/N=(rownum) Hwv

	String info = ImageInfo(GraphName, ImageWave, 0)
	String/G :hi_LP_temp:xaxis = StringByKey("XAXIS", info)
	String/G :hi_LP_temp:yaxis = StringByKey("YAXIS", info)
	String/G :hi_LP_temp:xwave = StringByKey("XWAVE", info)
	String/G :hi_LP_temp:ywave = StringByKey("YWAVE", info)
	SVAR xwave = :hi_LP_temp:xwave
	SVAR ywave = :hi_LP_temp:ywave
	if( stringmatch(xwave,"") || stringmatch(ywave,"") )
		print "X and Y waves are required"
		return -1
	endif

	K10 = NaN
	K11 = NaN


	Display /W=(156.75,112.25,647.25,457.25)
	ControlBar 50
	DoWindow/C hi_LP
	PopupMenu popVertOrHoriz,pos={0,1},size={135,20},title="direction", proc=hi_LP_popVertOrHoriz
	PopupMenu popVertOrHoriz,mode=1,popvalue="Vertical",value= #"\"Vertical;Horizontal\""
	SetVariable setvPoint,pos={150,1},size={100,15},title="point",value= :hi_LP_temp:TargetPos, proc=hi_LP_setvarProc
	SetVariable setvDelta,pos={150,27},size={100,15},title="delta",value= :hi_LP_temp:Delta, proc=hi_LP_setvarProc, limits={0,Inf,1}
	Button btnQuit,pos={450,26},size={50,20},title="quit", proc=hi_LP_btnQuit
	Button btnSave,pos={450,1},size={50,20},title="save", proc=hi_LP_btnSave
	ValDisplay valdispFrom,pos={300,1},size={100,15},title="from",barmisc={0,1000},value= #K10
	ValDisplay valdispUpto,pos={300,27},size={100,15},title="upto",barmisc={0,1000},value= #K11
	
	hi_LP_ChangeAxis()
	hi_LP_DrawLine()
	hi_LP_Plot()
End

Function hi_LP_btnSave(ctrlName) : ButtonControl
	String ctrlName
	SVAR VorH = :hi_LP_temp:VorH
	SVAR xwave = :hi_LP_temp:xwave
	SVAR ywave = :hi_LP_temp:ywave
	NVAR TargetPos = :hi_LP_temp:TargetPos
	NVAR Delta = :hi_LP_temp:Delta
	NVAR ValFrom = :hi_LP_temp:ValFrom
	NVAR ValUpto = :hi_LP_temp:ValUpto
		
	String NewWaveName
	String ValNote
	sprintf NewWaveName, "%s_point%ddelta%d", VorH, TargetPos, Delta
	sprintf ValNote, "from %g upto %g", ValFrom, ValUpto
	if(stringmatch(VorH, "V"))
		Duplicate Vwv, $NewWaveName
		Display $NewWaveName vs $ywave
	elseif(stringmatch(VorH, "H"))
		Duplicate Hwv, $NewWaveName
		Display $NewWaveName vs $xwave
	endif

	Note $NewWaveName, ValNote

End

Function hi_LP_ChangeAxis()
	SVAR VorH = :hi_LP_temp:VorH
	SVAR xwave = :hi_LP_temp:xwave
	SVAR ywave = :hi_LP_temp:ywave
	SVAR GraphName = :hi_LP_temp:GraphName
	
	String CurrentTrace = TraceNameList(GraphName,";",0)
	CurrentTrace = CurrentTrace[0, strlen(CurrentTrace)-2]	// remove ";"

	RemoveFromGraph/Z/W=hi_LP $CurrentTrace
	
	if(stringmatch(VorH, "V"))
		AppendToGraph/W=hi_LP Vwv vs $ywave
	elseif(stringmatch(VorH, "H"))
		AppendToGraph/W=hi_LP Hwv vs $xwave
	endif


End

Function hi_LP_Plot()

	SVAR VorH = :hi_LP_temp:VorH
	SVAR ImageWave = :hi_LP_temp:ImageWave
	NVAR TargetPos = :hi_LP_temp:TargetPos
	NVAR Delta = :hi_LP_temp:Delta
	WAVE imgwv = $ImageWave
	Variable i,j
	Variable wvSize

	if(stringmatch(VorH,"V"))
		WAVE Vwv
		Vwv = 0
		wvSize = DimSize($ImageWave, 1)	// column
		for(i=0; i<wvSize; i+=1)
			for(j=TargetPos-Delta; j<=TargetPos+Delta; j+=1)
				Vwv[i] += imgwv[j][i]
			endfor
		endfor
		Vwv /= (2*Delta + 1)
	elseif(stringmatch(VorH,"H"))
		WAVE Hwv
		Hwv = 0
		wvSize = DimSize($ImageWave, 0)	// row
		for(i=0; i<wvSize; i+=1)
			for(j=TargetPos-Delta; j<=TargetPos+Delta; j+=1)
				Hwv[i] += imgwv[i][j]
			endfor
		endfor
		Hwv /= (2*Delta + 1)
	endif

End




Function hi_LP_setvarProc (ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum	// value of variable as number
	String varStr		// value of variable as string
	String varName	// name of variable

	SVAR VorH = :hi_LP_temp:VorH
	SVAR xwave = :hi_LP_temp:xwave
	SVAR ywave = :hi_LP_temp:ywave
	NVAR ValFrom = :hi_LP_temp:ValFrom
	NVAR ValUpto = :hi_LP_temp:ValUpto
	NVAR TargetPos = :hi_LP_temp:TargetPos
	NVAR Delta = :hi_LP_temp:Delta

	if(stringmatch(VorH, "V"))
		WAVE wv = $xwave
	elseif(stringmatch(VorH,"H"))
		WAVE wv = $ywave
	endif


	ValFrom = wv[TargetPos - Delta]
	ValUpto = wv[TargetPos + Delta]
	
	K10 = ValFrom
	K11 = ValUpto

	hi_LP_DrawLine()

End


Function hi_LP_popVertOrHoriz(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr


	SVAR VorH = :hi_LP_temp:VorH
	if(stringmatch(popStr, "Horizontal"))
		VorH = "H"
	elseif(stringmatch(popStr,"Vertical"))
		VorH = "V"
	endif
	
	hi_LP_ChangeAxis()
	hi_LP_DrawLine()

End


Function hi_LP_DrawLine()

	NVAR TargetPos = :hi_LP_temp:TargetPos
	NVAR Delta = :hi_LP_temp:Delta
	SVAR VorH = :hi_LP_temp:VorH
	SVAR GraphName = :hi_LP_temp:GraphName
	SVAR xaxis = :hi_LP_temp:xaxis
	SVAR yaxis = :hi_LP_temp:yaxis
	SVAR xwave = :hi_LP_temp:xwave
	SVAR ywave = :hi_LP_temp:ywave
	WAVE wvx = $xwave
	WAVE wvy = $ywave	


	SetDrawLayer/W=$GraphName/K userfront
	SetDrawEnv/W=$GraphName linethick = 2, linefgc = (0,0,65535), save
	
	if(stringmatch(VorH, "V"))
		SetDrawEnv/W=$GraphName xcoord = $xaxis, ycoord = prel, save
		DrawLine/W=$GraphName wvx[TargetPos + Delta], 0, wvx[TargetPos + Delta], 1
		DrawLine/W=$GraphName wvx[TargetPos - Delta], 0, wvx[TargetPos - Delta], 1
	elseif(stringmatch(VorH, "H"))
		SetDrawEnv/W=$GraphName xcoord = prel, ycoord = $yaxis, save
		DrawLine/W=$GraphName 0, wvy[TargetPos + Delta], 1, wvy[TargetPos + Delta]
		DrawLine/W=$GraphName 0, wvy[TargetPos - Delta], 1, wvy[TargetPos - Delta]

	endif
	hi_LP_Plot()
End




Function hi_LP_btnQuit(ctrlName) : ButtonControl
	String ctrlName
	SVAR GraphName = :hi_LP_temp:GraphName
	SetDrawLayer/W=$GraphName/K userfront
	DoWindow/K hi_LP
	KillDataFolder :hi_LP_temp
	KillWaves Hwv, Vwv
End
