#pragma rtGlobals=1		// Use modern global access method.


Function hi_LinesCalib()	// Lines Calibration
	
	NewDataFolder/O root:hi_LinesCalibTEMP
	
	// our(Akiyama group) Ne lamp has (only) those lines
	// add or remove any lines as your needs
	String/G root:hi_LinesCalibTEMP:Ne = ""
	SVAR Ne = root:hi_LinesCalibTEMP:Ne
	Ne += "703.2413 (Ne);717.3938 (Ne);724.5167 (Ne);753.5774 (Ne);754.4044 (Ne);783.9055 (Ne);794.3181 (Ne)"
	Ne += ";758.7411 (Kr);760.1544 (Kr);768.5244 (Kr);769.4538 (Kr)"
	
	String/G root:hi_LinesCalibTEMP:CurrentCursol = "A"
	Variable/G root:hi_LinesCalibTEMP:CurrentLine = 999.999
	
	NewPanel /W=(537,79,840,130) as "Calibration by Atomic Lines"
	DoWindow/C hi_LinesCalib_panel
	SetDrawEnv fname="Arial", save

	// Line
	DrawText 9,44,"Target line:"
	PopupMenu popWl,pos={85,27},size={104,20}, proc=hi_LinesCalib_LUpdate	// Lines Update
	PopupMenu popWl,mode=1,bodyWidth= 104,value= #"root:hi_LinesCalibTEMP:Ne"

	// Cursol
	DrawText 9,20,"Info Cursol:"
	PopupMenu popCursol,pos={98,3},size={56,20}, proc=hi_LinesCalib_CUpdate // Cursol Update
	PopupMenu popCursol,mode=1,value= #"\"A;B\""
	
	// Buttons
	Button btnGo,pos={200,5},size={40,40},proc=hi_LinesCalib_exec,title="Go"	
	Button btnGo,font="Arial"		
	Button btnQuit,pos={253,5},size={40,40},proc=hi_LinesCalib_quit,title="Quit"
	Button btnQuit,font="Arial"
End

Function hi_LinesCalib_exec(ctrlName) : ButtonControl
	String ctrlName
	
	NVAR CurrentLine = root:hi_LinesCalibTEMP:CurrentLine
	SVAR CurrentCursol = root:hi_LinesCalibTEMP:CurrentCursol

	Variable CurrentX, CurrentP	// X value and Point
	String wvname	// the wave where current cursol is on

	If(stringmatch(CurrentCursol, "A"))
		CurrentX = hcsr(A)
		CurrentP = pcsr(A)
		wvname = CsrWave(A)
		WAVE wv = CsrWaveRef(A)
	elseif (stringmatch(CurrentCursol, "B"))
		CurrentX = hcsr(B)
		CurrentP = pcsr(B)
		wvname = CsrWave(B)
		WAVE wv = CsrWaveRef(B)
	else
		print "unexpected error !"
		abort
	endif
	
	String TextStr, TextName
	sprintf TextStr, "\F'Courier New'%g[nm]\r(%+4.4gnm away)", CurrentLine, CurrentX - CurrentLine
	sprintf TextName, "txt%d", CurrentP
	Tag/C/N=$TextName $wvname, pnt2x(wv, CurrentP), TextStr
End

Function hi_LinesCalib_quit(ctrlName) : ButtonControl
	String ctrlName
	
	KillDataFolder root:hi_LinesCalibTEMP
	DoWindow/K hi_LinesCalib_panel
End

// Lines Update
Function hi_LinesCalib_LUpdate(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr
	
	NVAR CurrentLine = root:hi_LinesCalibTEMP:CurrentLine
	CurrentLine = str2num(popStr)

End

// Cursol Update
Function hi_LinesCalib_CUpdate(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr
	
	SVAR CurrentCursol = root:hi_LinesCalibTEMP:CurrentCursol
	CurrentCursol = popStr

End


// Ne 700nm - 800nm
// from NIST
// http://physics.nist.gov/cgi-bin/AtData/lines_form
// -----------------------------
// Spec.   | Wavelength | Rel. |
//         |    Air     | Int. |      
//         |    (nm)    |      |      
// -----------------------------
// Ne I    |  702.40504 |  500 |      
// Ne I    |  703.24131 | 1000 |      
// Ne I    |  705.12923 |   70 |      
// Ne I    |  705.91074 |  200 |      
// Ne I    |  711.23106 |   10 |      
//         |            |      |      
// Ne I    |  717.39381 | 1000 |      
// Ne II   |  721.320   |  150 |      
// Ne II   |  723.519   |  150 |      
// Ne I    |  724.51666 | 1000 |      
// Ne I    |  730.4844  |   30 |      
//         |            |      |      
// Ne II   |  734.394   |  150 |      
// Ne I    |  743.88984 |  300 |      
// Ne I    |  747.24386 |   50 |      
// Ne I    |  748.88712 |  500 |      
// Ne II   |  749.210   |  100 |      
//         |            |      |      
// Ne II   |  752.282   |  150 |      
// Ne I    |  753.57741 |  300 |      
// Ne I    |  754.40443 |  100 |      
// Ne I    |  772.46281 |   10 |      
// Ne II   |  774.074   |  120 |      
//         |            |      |      
// Ne I    |  783.30303 |    7 |      
// Ne I    |  783.90546 |   30 |      
// Ne I    |  783.99893 |    1 |      
// Ne IX   |  792.2     |      |      
// Ne II   |  792.620   |  120 |      
//         |            |      |      
// Ne I    |  792.71177 |   40 |      
// Ne IX   |  793.4     |      |      
// Ne I    |  793.69961 |   70 |      
// Ne I    |  794.31814 |  200 |      
// Ne I    |  794.41411 |   20 |      
//         |            |      |      
// Ne VIII |  797.5     |      |      
// Ne IX   |  799.8     |      |      
// -----------------------------

// Kr 740nm - 780nm
//---------------------------
//Spec. | Wavelength | Rel. |
//      |    Air     | Int. |
//      |    (nm)    |      |
//---------------------------
//Kr II |   740.702  |  400 |
//Kr I  |   742.5541 |   60 |
//Kr II |   743.578  |  200 |
//Kr I  |   748.6862 |  100 |
//Kr II |   752.446  |  300 |
//      |            |      |
//Kr I  |   758.7411 | 1000 |
//Kr I  |   760.1544 | 2000 |
//Kr II |   764.116  |  150 |
//Kr I  |   768.5244 | 1000 |
//Kr I  |   769.4538 | 1200 |
//      |            |      |
//Kr II |   773.569  |  250 |
//Kr I  |   774.6827 |  150 |
//---------------------------