#pragma rtGlobals=1		// Use modern global access method.
// hi_PLEhelper
// This procedures help one to get PLE data from raw PL spectra.
// The procedures assume many PL spectra appended in one Graph window, and same xwave.
// (It seems to be a little complicated to deal with the waves which have different xwaves.)
// 


Function hi_PLEhelper_Panel()

	NewDataFolder/O root:hi_PLEhelper_temp
	Variable/G root:hi_PLEhelper_temp:RadioWhichMethod = 2
	Variable/G root:hi_PLEhelper_temp:ptFrom
	Variable/G root:hi_PLEhelper_temp:ptUpto

	NewPanel /W=(150,77,582,176)	
	DoWindow/C hi_PLEhelper

	Button btnQuit,pos={342,62},size={50,20},proc=hi_PLEhelper_btnQuit,title="Quit", font="Arial"
	Button btnExec,pos={342,29},size={50,20},proc=hi_PLEhelper_btnExec,title="Execute", font="Arial"

	// assume the largest point as 1340
	SetVariable setvarFrom,pos={44,37},size={100,15},title="From", format="%d", font="Courier New"
	SetVariable setvarFrom,limits={0,1339,1},value= root:hi_PLEhelper_temp:ptFrom
	SetVariable setvarUpto,pos={44,63},size={101,15},title="Upto", format="%d", font="Courier New"
	SetVariable setvarUpto,limits={0,1339,1},value= root:hi_PLEhelper_temp:ptUpto

	CheckBox chkIntInt,pos={195,27},size={117,14},proc=hi_PLEhelper_radio,title="integrated intensity",font="Arial",value= 0,mode=1
	CheckBox chkXatMaxY,pos={195,47},size={104,14},proc=hi_PLEhelper_radio,title="x value at max y",font="Arial",value= 1,mode=1
	CheckBox chkYatMaxY,pos={195,67},size={104,14},proc=hi_PLEhelper_radio,title="y value at max y",font="Arial",value= 0,mode=1

	GroupBox grpPoint,pos={23,8},size={152,82},title="target region (in point)",font="Arial"
	GroupBox grpOperation,pos={187,8},size={139,81},title="desired data",font="Arial"

End

Function hi_PLEhelper_btnQuit (ctrlName) : ButtonControl
	String ctrlName
	hi_PLEhelper_Quit()
End

Function hi_PLEhelper_Quit()
	DoWindow/K hi_PLEhelper
	KillDataFolder root:hi_PLEhelper_temp
End

Function hi_PLEhelper_btnExec(ctrlName) : ButtonControl
	String ctrlName
	
	String TargetWin = WinName(0,1)
	Variable i = -1	// in order to deal with the 'initial execution' of do-while loop
	
	do
		i += 1
	while( WaveExists(WaveRefIndexed(TargetWin, i, 2)) )
	// now 'i' is equivalent to the number of the appended waves
	
	if(i==0)
		print "no wave ?! exiting..."
		hi_PLEhelper_Quit()
	endif
	
	Variable AppendedNum = i
	Make/N=(AppendedNum) NewWv
	NVAR RadioWhichMethod = root:hi_PLEhelper_temp:RadioWhichMethod
	NVAR ptFrom = root:hi_PLEhelper_temp:ptFrom
	NVAR ptUpto = root:hi_PLEhelper_temp:ptUpto
	Variable j
	String NewWvNameSuffix
	
	if(RadioWhichMethod == 1)	// integrated intensity
	
		Variable IntInt		// integrated intensity
		for(i=0; i<=AppendedNum-1; i+=1)
			WAVE wv = WaveRefIndexed(TargetWin, i, 1)	// Y wave
			IntInt = 0
			for(j=ptFrom; j<=ptUpto; j+=1)
				IntInt += wv[j]
			endfor
			NewWv[i] = IntInt
		endfor
		NewWvNameSuffix = "integral"
		
	elseif( (RadioWhichMethod == 2) )	// X at max Y
	
		for(i=0; i<=AppendedNum-1; i+=1)
			WAVE wvy = WaveRefIndexed(TargetWin, i, 1)	// Y wave
			WAVE wvx = WaveRefIndexed(TargetWin, i, 2)	// X wave
			NewWv[i] = wvx[hi_GetDataAtMaxYValue(wvy, ptFrom, ptUpto, "P")]
		endfor
		NewWvNameSuffix = "XatMaxY"
		
	elseif( (RadioWhichMethod == 3) )	// Y at max Y
	
		for(i=0; i<=AppendedNum-1; i+=1)
			WAVE wvy = WaveRefIndexed(TargetWin, i, 1)	// Y wave
			NewWv[i] = hi_GetDataAtMaxYValue(wvy, ptFrom, ptUpto, "Y")
		endfor
		NewWvNameSuffix = "YatMaxY"
		
	else	// unexpected
		print "unexpected error !!!"
		hi_PLEhelper_Quit()
	endif
	
	String NewWvName
	sprintf NewWvName, "%s_%d_%d_%s", TargetWin, ptFrom, ptUpto, NewWvNameSuffix
	Rename NewWv, $NewWvName
	hi_PLEhelper_Quit()
End


Function hi_PLEhelper_radio(name, value) : CheckboxControl
	String name
	Variable value
	
	NVAR RadioWhichMethod = root:hi_PLEhelper_temp:RadioWhichMethod
	
	strswitch(name)
		case "chkIntInt":
			RadioWhichMethod = 1
			break
		case "chkXatMaxY":
			RadioWhichMethod = 2
			break
		case "chkYatMaxY":
			RadioWhichMethod = 3
			break
		default :
			print "unexpected error"	// seems to be critical
			abort
	endswitch
	
	CheckBox chkIntInt, value= (RadioWhichMethod==1)
	CheckBox chkXatMaxY, value= (RadioWhichMethod==2)
	CheckBox chkYatMaxY, value= (RadioWhichMethod==3)
End			

function hi_GetDataAtMaxYValue(wv, ptFrom, ptUpto, PorY)
	WAVE wv
	Variable ptFrom, ptUpto
	String PorY
	if(!WaveExists(wv))
		return NaN
	endif
	ptFrom = round(ptFrom)
	ptUpto = round(ptUpto)
	
	Variable i, MaxY, PointAtMaxY
	MaxY = -Inf
	for(i=ptFrom; i<=ptUpto; i+=1)
		if(MaxY < wv[i])
			MaxY = wv[i]
			PointAtMaxY = i
		endif
	endfor
	
	strswitch(PorY)
		case "P":
			return PointAtMaxY
			break
		case "Y":
			return maxY
			break
		default:
			return NaN
	endswitch
	
end