#pragma rtGlobals=1		// Use modern global access method.


// This function reads ASCII file output by DispSav (Pfeiffer vacuum, QuadStar 32bit)
//
// example:
// Prefix ...... "E:tmp:cycle"
// Suffix ...... ".asc"
// CycleFrom ... 2
// CycleUpto ... 10
//
// then, the following files will be read and corresponding matrix wave will be made
// E:tmp:cycle0002.asc
// E:tmp:cycle0003.asc
// ...
// E:tmp:cycle0010.asc
//
// besides, the X and Y waves (mass number and time in second measured from the 'origin') will be made.
// ("o_year" means "origin year")
//
// Be careful not to input invalid time... the error handling is not perfect !
Function hi_ReadQSMatrixPrompt()
	String Prefix, Suffix
	Variable CycleFrom, CycleUpto
	Variable o_year, o_month, o_day, o_hour, o_minute, o_sec

	Prompt Prefix, "Enter cycle-files' prefix"
	Prompt Suffix, "Enter cycle-files' suffix"
	Prompt CycleFrom, "Initial number of the desired cycles"
	Prompt CycleUpto, "Last number of the desired cycles"
	Prompt o_year, "The origin's year"
	Prompt o_month, "The origin's month"
	Prompt o_day, "The origin's day"
	Prompt o_hour, "The origin's hour"
	Prompt o_minute, "The origin's minute"
	Prompt o_sec, "The origin's second"
	DoPrompt "Enter parameters", Prefix, Suffix, CycleFrom, CycleUpto, o_year, o_month, o_day, o_hour, o_minute, o_sec
	if(V_Flag)
		return -1
	endif
	hi_ReadQSMatrix(Prefix, Suffix, CycleFrom, CycleUpto, o_year, o_month, o_day, o_hour, o_minute, o_sec)
End

Function hi_ReadQSMatrix(Prefix, Suffix, CycleFrom, CycleUpto, o_year, o_month, o_day, o_hour, o_minute, o_sec)
	String Prefix, Suffix
	Variable CycleFrom, CycleUpto
	Variable o_year, o_month, o_day, o_hour, o_minute, o_sec
	
	Variable refNum
	Variable i, j, k
		
	String ReadStr
	String FullPath

	Variable cycle, year, month, day, hour, minute, sec
	Variable IonCurrent, MassNumber


	// check whether the input origin is valid	
	if(hi_checkdate(o_year, o_month, o_day, o_hour, o_minute, o_sec) != 0)
		print "invalid origin"
		return -2
	endif
	Variable sec_origin = hi_date2sec(o_year, o_month, o_day, o_hour, o_minute, o_sec)
	
	// check whether files exist
	for(i=CycleFrom; i<=CycleUpto; i+=1)
		sprintf FullPath, "%s%04d%s", Prefix, i, Suffix	
		Open/R/Z=1 refNum as FullPath
		if(V_Flag != 0)
			printf "%s: <- File not found\r", FullPath
			return -1
		endif
		Close refNum
	endfor
	

	// create the matrix (initialy, it has no point)
	Make/D/N=(CycleUpto - CycleFrom + 1, 1)/O wvIonCurrent
	Make/D/N=(CycleUpto - CycleFrom + 1)/O wvTimeFromOrigin
	Make/D/N=0/O wvMassNumber

	String WaveNote
	sprintf WaveNote, "origin: %d/%d/%d, %d/%d/%d\rcycle: from %d to %d", o_year, o_month, o_day, o_hour, o_minute, o_sec, CycleFrom, CycleUpto
	Note wvTimeFromOrigin, WaveNote

	for(k=CycleFrom; k<=CycleUpto; k+=1)
		i = k - CycleFrom
		sprintf FullPath, "%s%04d%s", Prefix, k, Suffix
		Open/R/Z=1 refNum as FullPath
		
		// header region isn't required
		for(j=1;j<=19;j+=1)
			FReadLine/T=(num2char(13)) refNum, ReadStr
		endfor
	
		// this (20th) line contains time
		FReadLine/T=(num2char(13)) refNum, ReadStr
	
		// retrieve time data
		sscanf ReadStr, "%d\t%d/%d/%d\t%d:%d:%d", cycle, year, month, day, hour, minute, sec
		wvTimeFromOrigin[i] = hi_date2sec(year, month, day, hour, minute, sec) - sec_origin
		
		// this (21th) line isn't needed
		FReadLine/T=(num2char(13)) refNum, ReadStr

		// read main data
		j = 0
		FReadLine/T=(num2char(13)) refNum, ReadStr	// initial reading is required for the loop
		do
			sscanf ReadStr, "%g\t%g", MassNumber, IonCurrent

			if(i==0)	// in initial loop,
				InsertPoints/M=1 j, 1, wvIonCurrent	// enough columns
				InsertPoints/M=0 j, 1, wvMassNumber	//           rows and.....
				wvMassNumber[j] = MassNumber			// the wave of mass number have to be prepared
			endif

			wvIonCurrent[i][j] = IonCurrent
			j += 1
			FReadLine/T=(num2char(13)) refNum, ReadStr
		while(!stringmatch(ReadStr,""))
		Close refNum

	endfor
	DeletePoints/M=1 j, 1, wvIonCurrent
	MatrixTranspose wvIonCurrent
	
End

Function hi_date2sec(year, month, day, hour, minute, sec)
	Variable year, month, day, hour, minute, sec
	return date2secs(year, month, day) + ((60*hour + minute)*60 + sec)
End



// validation check (not perfect)
Function hi_checkdate(year, month, day, hour, minute, sec)
	Variable year, month, day, hour, minute, sec

	// year
	if(year<=2003)
		return 1
	endif
	
	// month
	if(month<=0 || month>=13)
		return 2
	endif
	
	// day
	if(day<=0 || day>=32)
		return 3
	endif
	
	// hour
	if(hour<0 || hour>23)
		return 4
	endif

	// minute
	if(minute<0 || minute>59)
		return 5
	endif

	// sec
	if(sec<0 || sec>59)
		return 6
	endif

	return 0
End