#pragma rtGlobals=1		// Use modern global access method.
// hi_ReadWS series
// The functions read the ascii files output by WinSpec .spe files.

Function hi_ReadWS_wl(FullPath)
	String FullPath
	// no photon energy, and offset of 10000
	hi_ReadWS_core(FullPath, 0, 10000)
End

Function hi_ReadWS_pe(FullPath)
	String FullPath
	// photon energy, and offset of 10000
	hi_ReadWS_core(FullPath, 1, 10000)
End


Function hi_ReadWS_core(FullPath, pe, MyOffset)
	String FullPath
	Variable pe, MyOffset

	// check of the argument -- pe	
	if( (pe!=0) && (pe!=1) )
		print "invalid parameter pe: " + num2str(pe)
		return -1
	endif
	
	// check of the argument -- FullPath
	Variable refnum
	Open/R/Z=1 refnum as FullPath
	if( V_flag != 0)	// error occured in opening the file
		print "invalid parameter FullPath: " + FullPath
		return -1
	endif
	Close refnum

	// load
	print "Reading...   " + FullPath
	LoadWave/Q/O/G/D/L={0,0,0,0,2}/B="N=wv_x; N=wv_y;"/A FullPath
	Wave wv_x
	Wave wv_y
	Duplicate wv_x, wv_p	// photon energy
	wv_p = 1239.8 / wv_x
	
	String fileName_noEx = ParseFilePath(3,S_fileName, ":", 0, 0)	// remove extension
	String wv_wl = fileName_noEx + "_wl"
	String wv_int = fileName_noEx + "_int"	
	String wv_pe = fileName_noEx + "_pe"
	Rename wv_x, $wv_wl
	Rename wv_y, $wv_int
	Rename wv_p, $wv_pe

	// calculate the number of spectra
	Variable SpectraNum = numpnts($wv_int) / 1340	// assume there are 1340 CCDs
	if( SpectraNum != round(SpectraNum) )		// in case SpectraNum is not integral
		print "mismatch in the number of spectra ... not 1340 ?"
		return -1
	endif

	// preparing the graph window (empty)
	preferences 1
	Display as fileName_noEx
	String WindowName = fileName_noEx + "_graph"
	DoWindow/C $WindowName
	
	// whether to plot against photon energy or not
	if(pe == 0)
		Wave wv_xmain = $wv_wl
		Wave wv_xsub = $wv_pe
	elseif(pe == 1)
		Wave wv_xmain = $wv_pe
		Wave wv_xsub = $wv_wl
	else	// unexpected error
		print "unexpected error !"
		return -1
	endif

	// dealing with multi-frames, if there are
	if(SpectraNum > 1)

		if(DataFolderExists("root:offset:") == 0)
			NewDataFolder/O root:offset
		endif

		Redimension/N=1340 $wv_wl, $wv_pe	// (Xwave) only first 1340 elements are needed
		String StoragePath
		sprintf StoragePath, "root:%s", fileName_noEx
		NewDataFolder/O $StoragePath
		sprintf StoragePath, "root:%s:", fileName_noEx	// note for the colon
		MoveWave wv_xmain, $StoragePath
		MoveWave wv_xsub, $StoragePath
		MoveWave $wv_int, $StoragePath
		SetDataFolder $StoragePath
	
		String strOffset = "root:offset:" + WindowName
		Variable/g $strOffset = MyOffset	// memorize default offset value to global variables
		
		Variable i, StartP, EndP
		String wv_int_EachFrame
		for(i=1; i<=SpectraNum; i+=1)
			StartP = 1340*(i-1)
			EndP = StartP + 1339
			sprintf wv_int_EachFrame, "%s_int_fra%03d", fileName_noEx, i
			Duplicate/D/R=[StartP,EndP] $wv_int, $wv_int_EachFrame
			AppendToGraph $wv_int_EachFrame vs wv_xmain
			ModifyGraph offset($wv_int_EachFrame) = {0, (i-1) * MyOffset}
		endfor
		KillWaves $wv_int
		SetDataFolder root:
		
	else	// single frame
		AppendToGraph $wv_int vs wv_xmain
	endif
	
	// Tweaking 
	ModifyGraph noLabel(left)=1
	Label left "intensity"
	if(pe==0)
		Label bottom "Wavelength [nm]"
	elseif(pe==1)
		Label bottom "Photon Energy [eV]"
	else
		print "unexpected error"
		return -1
	endif
	
	// housekeeping
	KillVariables/Z V_flag
	KillVariables/Z S_waveNames
	KillVariables/Z S_fileName
	KillVariables/Z S_path
	

End
