#pragma rtGlobals=1		// Use modern global access method.
//// Igor procedure RainBow
//// The procedure creats 2D wave with RGB information, and X index.
//// Using the wave as indexed color enable us to make an image plot via arbitrary color table.
//// coded by Hirotake Itoh, 2002 Dec 14

//// creat menu
//// start
//Menu "&Image"
//	"&Plot", hi_RB_main()
//end
//// end of menu

//// hi_RB_Make_Rainbow
//// The function creats a wave of rainbow, with X index.
//// To modify X index manualy, go Data -> Change wave scaling
//// start
function hi_RB_MakeRainbow(val_w, val_b)	// val_s represents the value of START(white), and val_e represents END(black).

	variable val_w, val_b
	variable i	// just index
	svar targetwavestring = hi_RB_targetwavestring
	string rainbowname = "rainbow_" + targetwavestring
	
	Make/N=(100,3)/W/U/O $rainbowname // make the wave (100 rows, 3 columns, unsigned INT (16bit), overwrite)
	wave rainbow = $rainbowname

	///// column 0 (Red) ///////
 
	for(i=0;i<=35;i+=1)
		rainbow[i][0] = 65535
	endfor
	
	for(i=36;i<=69;i+=1)
		rainbow[i][0] = 65535 - (i-35)*1872
	endfor
	
	for(i=70;i<=84;i+=1)
		rainbow[i][0] = (i-69)*2184
	endfor
	
	for(i=85;i<=98;i+=1)
		rainbow[i][0] = 32767 - (i-84)*2184
	endfor

	rainbow[99][0] = 0

	///// column 0 (Red) ends /////

	///// column 1 (Green) //////

	for(i=0;i<=13;i+=1)
		rainbow[i][1] = 65535 - i*4681
	endfor

	for(i=14;i<=34;i+=1)
		rainbow[i][1] = (i-14)*3121
	endfor

	for(i=35;i<=69;i+=1)
		rainbow[i][1] = 65535
	endfor

	for(i=70;i<=83;i+=1)
		rainbow[i][1] = 65535 - (i-69)*4369
	endfor

	for(i=84;i<=99;i+=1)
		rainbow[i][1] = 0
	endfor

	///// column 1 (Green) ends //////

	///// column 2 (Blue) ////////

	for(i=0;i<=13;i+=1)
		rainbow[i][2] = 65535 - i*4681
	endfor

	for(i=14;i<=56;i+=1)
		rainbow[i][2] = 0
	endfor

	for(i=57;i<=69;i+=1)
		rainbow[i][2] = (i-56)*4681
	endfor

	for(i=70;i<=84;i+=1)
		rainbow[i][2] = 65535
	endfor

	for(i=85;i<=97;i+=1)
		rainbow[i][2] = 65535 - (i-84)*4681
	endfor

	rainbow[98][2] = 0
	rainbow[99][2] = 0
	
	///// column 2 (Blue) ends ////////	


	SetScale/I x val_w, val_b,"", rainbow // set "rainbow"'s scale from "start" to "end"	
	
end
//// end of hi_RB_MakeRainbow

//// hi_RB_main()
//// The function creats global variables, panel with buttons, popup.
//// start
function hi_RB_main()

	string/g hi_RB_targetwavestring
	variable/g hi_RB_white = 5000	// the value which is represented by white
	variable/g hi_RB_black = 50	// the value which is represented by black
	
	newpanel/w=(350,150,600,220)
	DoWindow/C/T/r hi_RB_panel,"Image plot settings"	// name, title
	setdrawenv fname="Arial",fillpat=0,save			// default setting
	
	PopupMenu RB_popup_w pos={2,7},proc=hi_RB_popup_wave,title="Choose the Matrix"	// Title
	PopupMenu RB_popup_w value= "_none_;" + WaveList("*",";","DIMS:2")					// list of matrix (not 1D wave)
	
	Button RB_executeplot pos={13,32},size={84,33},proc=hi_RB_ExecutePlot,title="plot"
	Button RB_quit pos={129,32}, size={84,33},proc=hi_RB_quit,title="quit"

end
//// end of hi_RB_main()

//// popup
function hi_RB_popup_wave(ctrlName,popNum,popStr) : popupmenucontrol
	string ctrlName,popStr
	variable popNum
	
	svar targetwavestring = hi_RB_targetwavestring
	targetwavestring = popStr	// substitute popup-string(name of the wave) into global string
end

//// button
function hi_RB_ExecutePlot(ctrlname) : ButtonControl
	string ctrlname
	svar targetwavestring = hi_RB_targetwavestring
	string graphtitle = "image_" + targetwavestring
	string rainbowname = "rainbow_" + targetwavestring
	wave targetwave = $targetwavestring

	/// make rainbow
	hi_RB_MakeRainbow(5000, 50)
	
	/// plot main graph
	Display as graphtitle;AppendImage targetwave
	controlbar 30
	SetVariable RB_min pos={10,5},size={130,30},title="white value"
	SetVariable RB_min limits={-Inf,Inf,10},value=hi_RB_white,proc=hi_RB_minval	// in setvariable, value MUST be set by global variable
	SetVariable RB_max size={130,30},title="black value"
	SetVariable RB_max limits={-Inf,Inf,10},value=hi_RB_black,proc=hi_RB_maxval
	Button RB_update size={50,20},proc=hi_RB_update,title="Update"
	ModifyImage $targetwavestring cindex= $rainbowname
	
	/// plot color bar
	string ColorBarWaveString = "colorbar_" + targetwavestring 
	make/o/n=(100,1) $ColorBarWaveString
	wave colorbar = $ColorBarWaveString
	// initialization of colorbar. 5000 for white, and 50 for black
	variable i
	for(i=0;i<=99;i+=1)
		colorbar[i][0] = 5000 - 50*i
	endfor
	setscale/I x 5000,50,"",colorbar
	
	display;AppendImage $ColorBarWaveString
	ModifyImage $ColorBarWaveString cindex= $rainbowname
	ModifyGraph tick(left)=3,noLabel(left)=2	// no ticks, no label for left axis
	ModifyGraph axOffset(left)=-4
	
	// erase the panel
	hi_RB_quit("RB_quit")
end

function hi_RB_quit(ctrlname) : Buttoncontrol
	string ctrlname
	dowindow/k hi_RB_panel
end

/// rescale rainbow
function hi_RB_update(ctrlname) : Buttoncontrol
	string ctrlname
	nvar whiteval = hi_RB_white
	nvar blackval = hi_RB_black
	svar targetwavestring = hi_RB_targetwavestring
	wave targetwave = $targetwavestring
	string rainbowname = "rainbow_" + targetwavestring
	wave rainbow = $rainbowname
	string ColorBarWaveString = "colorbar_" + targetwavestring 
	wave colorbar = $ColorBarWaveString
			
	// rescale image plot
	SetScale/I x whiteval, blackval,"", rainbow // set "rainbow"'s scale from "start" to "end"	
	
	// rescale colorbar
	variable i
	for(i=0;i<=99;i+=1)
		colorbar[i][0] = whiteval - i*(whiteval - blackval)/99
	endfor
	setscale/I x whiteval, blackval,"",colorbar
end

/// setvariable (do nothing)
Function hi_RB_minval(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum	// value of variable as number
	String varStr		// value of variable as string
	String varName		// name of variable
end

Function hi_RB_maxval(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum	// value of variable as number
	String varStr		// value of variable as string
	String varName		// name of variable
end
